@@ -1,12 +1,16 @@
 from tr.Task import *
 import textwrap
+from argparse import Namespace as Args
 
 
-def _active_task_name(config: Config, args) -> str:
-    task_name = config.default_task_name() if args.task is None else args.task
-    if task_name is None:
+def _active_task_name(config: Config) -> str:
+    if config.args and config.args.task:
+        task = config.args.task
+    else:
+        task = config.default_task_name()
+    if task is None:
         raise TaskException("No main task name was given")
-    return task_name
+    return task
 
 
 def _show_task(task: Task, full_details: bool) -> None:
@@ -23,6 +27,7 @@ def _show_task(task: Task, full_details: bool) -> None:
         first = True
         for line in text.split('\n'):
             for in_line in textwrap.wrap(line, width=80):
+
                 if first:
                     print_val(title, in_line)
                     first = False
@@ -40,8 +45,8 @@ def _show_task(task: Task, full_details: bool) -> None:
             print_val("Short description:", task.short_desc)
         if task.long_desc:
             print_blob("Description:", task.long_desc)
-        print_bool("Hidden", task.hidden)
-        print_bool("Abstract", task.abstract)
+        print_bool("Hidden:", task.hidden)
+        print_bool("Abstract:", task.abstract)
     print_bool("Use shell: ", task.shell)
     if task.shell:
         shell_title = "Shell path:"
@@ -107,15 +112,17 @@ def _show_task(task: Task, full_details: bool) -> None:
         count += 1
 
 
-def show_task_info(args: Args, config: Config) -> None:
-    task_name = _active_task_name(config, args)
+def show_task_info(config: Config) -> None:
+    task_name = _active_task_name(config)
     task = Task(task_name, config)
-    if args.expand:
-        task.expand_args(config.expander)
+    if config.args.expand:
+        task.expand()
     _show_task(task, True)
 
 
-def list_tasks(config: Config, show_all: bool, names_only: bool):
+def list_tasks(config: Config):
+    show_all: bool = config.args.all
+    names_only: bool = config.args.names_only
     info("Listing tasks show_all={} names_only={}", show_all, names_only)
     print_fmt = "{:<24}{:<6}{}"
     err_print_fmt = "{:<30}{}"
@@ -152,22 +159,71 @@ def list_tasks(config: Config, show_all: bool, names_only: bool):
         print(print_fmt.format(task_name, flags, desc[-55:]))
 
 
-def run_task(config: Config, args: Args) -> int:
-    task_name = _active_task_name(config, args)
+def args_update(task, args: Args) -> None:
+    if args.stop_on_error:
+        task.stop_on_error = args.stop_on_error
+    if args.command:
+        task.commands = args.command
+    if args.cwd:
+        task.cwd = args.cwd
+    if args.shell:
+        task.shell = (args.shell == TASK_YES_TOKEN)
+    if args.shell_path:
+        task.shell_path = args.shell_path
+    if args.env:
+        task.env = {}
+        for e in args.env:
+            e_name, e_value = parse_assignment_str(e)
+            task.env[e_name] = e_value
+
+    if args.c_image:
+        task.c_image = args.c_image
+    if args.c_volume:
+        task.c_volumes = args.c_volume
+    if args.c_interactive:
+        task.c_interactive = (args.c_interactive == TASK_YES_TOKEN)
+    if args.c_tty:
+        task.c_tty = (args.c_tty == TASK_YES_TOKEN)
+    if args.c_flags:
+        task.c_flags = args.c_flags
+    if args.c_exec:
+        task.c_exec = args.c_exec
+    if args.c_rm:
+        task.c_rm = (args.c_rm == TASK_YES_TOKEN)
+    if args.c_tool:
+        task.c_tool = args.c_tool
+    if args.c_shell:
+        task.c_shell = (args.c_shell == TASK_YES_TOKEN)
+    if args.c_shell_path:
+        task.c_shell_path = args.c_shell_path
+    if args.c_cwd:
+        task.c_cwd = args.c_cwd
+    if args.c_env:
+        task.c_env = {}
+        for e in args.c_env:
+            e_name, e_value = parse_assignment_str(e)
+            task.c_env[e_name] = e_value
+    for v in args.variable:
+        key, val = parse_assignment_str(v)
+        task.vars_map[key] = val
+
+
+def run_task(config: Config) -> int:
+    task_name = _active_task_name(config)
     info("Running task '{}'", task_name)
     task = Task(task_name, config)
-    task.args_update(args)
-    task.expand_args(config.expander)
-    if args.summary:
+    args_update(task, config.args)
+    task.expand()
+    if config.args.summary:
         _show_task(task, False)
         print("-" * 70)
         sys.stdout.flush()
     return task.run()
 
 
-def dump_task(config: Config, args: Args):
-    task_name = _active_task_name(config, args)
-    print(json.dumps(config.get_task_desc(task_name, args.includes), indent=4))
+def dump_task(config: Config):
+    task_name = _active_task_name(config)
+    print(json.dumps(config.get_task_desc(task_name, config.args.includes), indent=4))
 
 
 def dump_config(config: Config):
